@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
 
 __author__ = 'F. A. Bastiaan von Meijenfeldt'
-__version__ = '5.0.5'
-__date__ = 'May 26, 2020'
+__version__ = '5.1.2'
+__date__ = '15 July, 2020'
